==> jc-1.4.0.tar.gz: soot/jimple/parser/node/X2PStatement.h <==
// public final class soot.jimple.parser.node.X2PStatement

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cd3aa1ff293102c9 soot_jimple_parser_node_X2PStatement
// @dep_class ba0190aee55bf9 soot_jimple_parser_node_XPStatement

// header file dependencies
// @dep_header soot_jimple_parser_node_XPStatement

#include "soot/jimple/parser/node/XPStatement.h"

#ifndef _JC_soot_jimple_parser_node_X2PStatement_H_
#define _JC_soot_jimple_parser_node_X2PStatement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PStatement$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PStatement$sub_refs	_jc_soot_jimple_parser_node_X2PStatement$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PStatement$sub_nonrefs	_jc_soot_jimple_parser_node_X2PStatement$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PStatement$refs	_jc_soot_jimple_parser_node_X2PStatement$refs;
typedef struct _jc_soot_jimple_parser_node_X2PStatement$nonrefs	_jc_soot_jimple_parser_node_X2PStatement$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PStatement$object	_jc_soot_jimple_parser_node_X2PStatement$object;

typedef const struct _jc_soot_jimple_parser_node_X2PStatement$vmethods	_jc_soot_jimple_parser_node_X2PStatement$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PStatement$vtable	_jc_soot_jimple_parser_node_X2PStatement$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PStatement$vtype	_jc_soot_jimple_parser_node_X2PStatement$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PStatement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *);
extern void _jc_soot_jimple_parser_node_X2PStatement$method$_init$0230cfbd383777ec(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_PStatement$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PStatement$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PStatement$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *);
extern struct _jc_soot_jimple_parser_node_PStatement$object *_jc_soot_jimple_parser_node_X2PStatement$method$getPStatement$13c0d05f2e0b6962(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *);
extern void _jc_soot_jimple_parser_node_X2PStatement$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PStatement$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_X2PStatement$method$setPStatement$7ab98acad3cb0540(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_PStatement$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PStatement$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$getPStatement$13c0d05f2e0b6962;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$setPStatement$7ab98acad3cb0540;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PStatement$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *);
	struct _jc_soot_jimple_parser_node_PStatement$object	*(*getPStatement$13c0d05f2e0b6962)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setPStatement$7ab98acad3cb0540)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_PStatement$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PStatement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPStatement$vmethods	soot_jimple_parser_node_XPStatement;
	_jc_soot_jimple_parser_node_X2PStatement$vmethods	soot_jimple_parser_node_X2PStatement;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PStatement$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PStatement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PStatement$sub_refs {
	struct _jc_soot_jimple_parser_node_PStatement$object	*__5fpStatement__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PStatement$refs {
    _jc_soot_jimple_parser_node_X2PStatement$sub_refs	soot_jimple_parser_node_X2PStatement;
    _jc_soot_jimple_parser_node_XPStatement$sub_refs	soot_jimple_parser_node_XPStatement;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PStatement$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PStatement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPStatement$sub_nonrefs	soot_jimple_parser_node_XPStatement;
    _jc_soot_jimple_parser_node_X2PStatement$sub_nonrefs	soot_jimple_parser_node_X2PStatement;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PStatement$object {
	_jc_soot_jimple_parser_node_X2PStatement$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PStatement$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PStatement$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PStatement$vtype _jc_soot_jimple_parser_node_X2PStatement$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PStatement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PStatement$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PStatement_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/X2PStatement.h <==
// public final class soot.jimple.parser.node.X2PStatement

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cd3aa1ff293102c9 soot_jimple_parser_node_X2PStatement
// @dep_class ba0190aee55bf9 soot_jimple_parser_node_XPStatement

// header file dependencies
// @dep_header soot_jimple_parser_node_XPStatement

#include "soot/jimple/parser/node/XPStatement.h"

#ifndef _JC_soot_jimple_parser_node_X2PStatement_H_
#define _JC_soot_jimple_parser_node_X2PStatement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PStatement$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_X2PStatement$sub_refs	_jc_soot_jimple_parser_node_X2PStatement$sub_refs;
typedef struct _jc_soot_jimple_parser_node_X2PStatement$sub_nonrefs	_jc_soot_jimple_parser_node_X2PStatement$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PStatement$refs	_jc_soot_jimple_parser_node_X2PStatement$refs;
typedef struct _jc_soot_jimple_parser_node_X2PStatement$nonrefs	_jc_soot_jimple_parser_node_X2PStatement$nonrefs;
typedef struct _jc_soot_jimple_parser_node_X2PStatement$object	_jc_soot_jimple_parser_node_X2PStatement$object;

typedef const struct _jc_soot_jimple_parser_node_X2PStatement$vmethods	_jc_soot_jimple_parser_node_X2PStatement$vmethods;
typedef const struct _jc_soot_jimple_parser_node_X2PStatement$vtable	_jc_soot_jimple_parser_node_X2PStatement$vtable;
typedef const struct _jc_soot_jimple_parser_node_X2PStatement$vtype	_jc_soot_jimple_parser_node_X2PStatement$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_X2PStatement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PStatement$method$_init$0230cfbd383777ec(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_PStatement$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_X2PStatement$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_X2PStatement$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PStatement$object *_jc_soot_jimple_parser_node_X2PStatement$method$getPStatement$13c0d05f2e0b6962(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PStatement$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PStatement$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_X2PStatement$method$setPStatement$7ab98acad3cb0540(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_PStatement$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_X2PStatement$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$getPStatement$13c0d05f2e0b6962;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$setPStatement$7ab98acad3cb0540;
extern _jc_method _jc_soot_jimple_parser_node_X2PStatement$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_X2PStatement$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PStatement$object	*(*getPStatement$13c0d05f2e0b6962)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setPStatement$7ab98acad3cb0540)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *, struct _jc_soot_jimple_parser_node_PStatement$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_X2PStatement$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_X2PStatement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_XPStatement$vmethods	soot_jimple_parser_node_XPStatement;
	_jc_soot_jimple_parser_node_X2PStatement$vmethods	soot_jimple_parser_node_X2PStatement;
};

// Vtype
struct _jc_soot_jimple_parser_node_X2PStatement$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_X2PStatement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PStatement$sub_refs {
	struct _jc_soot_jimple_parser_node_PStatement$object	*__5fpStatement__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PStatement$refs {
    _jc_soot_jimple_parser_node_X2PStatement$sub_refs	soot_jimple_parser_node_X2PStatement;
    _jc_soot_jimple_parser_node_XPStatement$sub_refs	soot_jimple_parser_node_XPStatement;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_X2PStatement$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_X2PStatement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_XPStatement$sub_nonrefs	soot_jimple_parser_node_XPStatement;
    _jc_soot_jimple_parser_node_X2PStatement$sub_nonrefs	soot_jimple_parser_node_X2PStatement;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_X2PStatement$object {
	_jc_soot_jimple_parser_node_X2PStatement$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_X2PStatement$vtype	*vtype;
	_jc_soot_jimple_parser_node_X2PStatement$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_X2PStatement$vtype _jc_soot_jimple_parser_node_X2PStatement$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_X2PStatement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_X2PStatement$class_object;

#endif	/* _JC_soot_jimple_parser_node_X2PStatement_H_ */
